@@ -1,9 +1,10 @@
 import datetime
+from warnings import warn
 
 try:
     import pytz
 except ImportError:
-    pass
+    warn("pytz is not found and it is used in some methods inside this library", ImportWarning)
 
 
 def get_iso_week_day(date: datetime.datetime, timezone: str) -> int:
