@@ -2,17 +2,18 @@ from functools import wraps
 from importlib import util as importlib_util
 from re import split
 from typing import Dict, Optional, Tuple
+from warnings import warn
 
 try:
     import jwt
 except ImportError:
-    pass
+    warn("PyJWT is not found and it is used in some methods inside this library", ImportWarning)
 
 try:
     from bson import ObjectId
     from bson.errors import InvalidId
 except ImportError:
-    pass
+    warn("bson is not found and it is used in some methods inside this library", ImportWarning)
 
 from werkzeug.routing import BaseConverter, ValidationError
 
