@@ -1,12 +1,12 @@
 import copy
 import datetime
 from functools import wraps
-from typing import Dict, Optional
+from typing import Dict, Optional, Tuple
 
 import jwt
 
 
-def encode_jwt(*, data: Dict, expiration_time_days: int, jwt_secret_key: str) -> str:
+def encode_jwt(*, data: Dict, expiration_time_days: int, jwt_secret_key: str) -> Tuple[str, int]:
     data_copy = copy.deepcopy(data)
     expiration_time = datetime.datetime.utcnow() + datetime.timedelta(
         days=expiration_time_days
@@ -14,7 +14,7 @@ def encode_jwt(*, data: Dict, expiration_time_days: int, jwt_secret_key: str) ->
     data_copy.update({"exp": expiration_time})
     data_copy.update({"iat": datetime.datetime.utcnow()})
     token = jwt.encode(data_copy, jwt_secret_key, algorithm="HS256")
-    return token
+    return token, int(expiration_time.timestamp())
 
 
 def decode_jwt(*, jwt_token: str, jwt_secret_key: str, verify_exp: bool = False) -> Dict:
