@@ -1,7 +1,8 @@
 import datetime
+import io
 import math
 from decimal import Decimal
-from typing import Dict, List, Optional, TypeVar
+from typing import Dict, List, NewType, Optional, Tuple, TypeVar
 from urllib.parse import urlparse
 
 TWOPLACES = Decimal(10) ** -2
@@ -9,6 +10,8 @@ DATETIME_FORMAT = "%Y-%m-%dT%H:%M:%S"
 DATE_FORMAT = "%Y-%m-%d"
 T = TypeVar("T")
 MB_BYTES = 1024 * 1024
+FileBytesExtension = NewType("FileBytesExtension", Tuple[io.BytesIO, str])
+
 
 
 def get_jwt_token(dictionary: Dict) -> Dict:
